RemoteDivergence

Enum RemoteDivergence 

pub enum RemoteDivergence {
    InSync,
    Ahead {
        commits: usize,
    },
    Behind {
        commits: usize,
    },
    Diverged {
        ahead: usize,
        behind: usize,
    },
    NoRemote,
}
Divergence state between a local branch and its tracking remote (upstream, falls back to origin).

This is distinct from BranchState::Diverged which tracks divergence from the parent branch (needs sync). RemoteDivergence tracks local vs remote (needs push/pull).

Variants



InSync

Local and remote are at the same commit.



Ahead

Local has commits not on remote (safe push).

Fields

commits: usize

Number of commits local is ahead of remote.



Behind

Remote has commits not on local (need pull).

Fields

commits: usize

Number of commits local is behind remote.



Diverged

Both have unique commits (need force push after rebase).

Fields

ahead: usize

Number of commits local is ahead of remote.

behind: usize

Number of commits local is behind remote.



NoRemote

No remote tracking branch exists (first push).