ConflictPrediction

Struct ConflictPrediction 

pub struct ConflictPrediction {
    pub commit: Oid,
    pub commit_summary: String,
    pub conflicting_files: Vec<String>,
}
Predicted conflict for a single commit during a rebase operation.

This is used by the conflict prediction system to warn users about potential conflicts before starting a sync operation.

Fields

commit: Oid

The commit that would cause conflicts.

commit_summary: String

The commit message (first line).

conflicting_files: Vec<String>

Files that would conflict when applying this commit.